@@ -28,6 +28,9 @@ class Fpm:
     self.runtimeDepsDict = parseYamlDict(os.path.join(config.work_dir, 'runtime.' + self.release_suffix + '.yaml'))
     self.develDepsDict = parseYamlDict(os.path.join(config.work_dir, 'devel.' + self.release_suffix + '.yaml'))
 
+    if config.tag_version:
+        self.release_suffix += '_' + config.release_tag.replace('/', '_')
+
   def run(self, name, version, deps, devel_deps, extra_deps, RPMS_GENERATED = []):
     """ Prepares arguments and executes fpm """
     fullVersion = version
